# Config file for the ecflow package
# Defines the following variables:
#
#  ecflow_FEATURES       - list of enabled features
#  ecflow_VERSION        - version of the package
#  ecflow_GIT_SHA1       - Git revision of the package
#  ecflow_GIT_SHA1_SHORT - short Git revision of the package
#


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was project-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

### computed paths
set_and_check(ecflow_CMAKE_DIR "${PACKAGE_PREFIX_DIR}/lib/cmake/ecflow")
set_and_check(ecflow_BASE_DIR "${PACKAGE_PREFIX_DIR}/.")
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(ECFLOW_CMAKE_DIR ${ecflow_CMAKE_DIR})
  set(ECFLOW_BASE_DIR ${ecflow_BASE_DIR})
endif()

### export version info
set(ecflow_VERSION           "5.14.0")
set(ecflow_GIT_SHA1          "")
set(ecflow_GIT_SHA1_SHORT    "")

if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(ECFLOW_VERSION           "5.14.0" )
  set(ECFLOW_GIT_SHA1          "" )
  set(ECFLOW_GIT_SHA1_SHORT    "" )
endif()

### has this configuration been exported from a build tree?
set(ecflow_IS_BUILD_DIR_EXPORT OFF)
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(ECFLOW_IS_BUILD_DIR_EXPORT ${ecflow_IS_BUILD_DIR_EXPORT})
endif()

### include the <project>-import.cmake file if there is one
if(EXISTS ${ecflow_CMAKE_DIR}/ecflow-import.cmake)
  set(ecflow_IMPORT_FILE "${ecflow_CMAKE_DIR}/ecflow-import.cmake")
  include(${ecflow_IMPORT_FILE})
endif()

### insert definitions for IMPORTED targets
if(NOT ecflow_BINARY_DIR)
  find_file(ecflow_TARGETS_FILE
    NAMES ecflow-targets.cmake
    HINTS ${ecflow_CMAKE_DIR}
    NO_DEFAULT_PATH)
  if(ecflow_TARGETS_FILE)
    include(${ecflow_TARGETS_FILE})
  endif()
endif()

### include the <project>-post-import.cmake file if there is one
if(EXISTS ${ecflow_CMAKE_DIR}/ecflow-post-import.cmake)
  set(ecflow_POST_IMPORT_FILE "${ecflow_CMAKE_DIR}/ecflow-post-import.cmake")
  include(${ecflow_POST_IMPORT_FILE})
endif()

### handle third-party dependencies
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(ECFLOW_LIBRARIES         "")
  set(ECFLOW_TPLS              "" )

  include(${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL)
endif()

### publish this file as imported
if( DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT )
  set(ecflow_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE})
  mark_as_advanced(ecflow_IMPORT_FILE)
  set(ECFLOW_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE})
  mark_as_advanced(ECFLOW_IMPORT_FILE)
endif()

### export features and check requirements
set(ecflow_FEATURES "PKGCONFIG;WARNINGS;COLOURED_OUTPUT;EXPORT_COMPILE_COMMANDS;EXPORT_COMPILE_COMMANDS")
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(ECFLOW_FEATURES ${ecflow_FEATURES})
endif()
foreach(_f ${ecflow_FEATURES})
  set(ecflow_${_f}_FOUND 1)
  set(ecflow_HAVE_${_f} 1)
  if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
    set(ECFLOW_HAVE_${_f} 1)
  endif()
endforeach()
check_required_components(ecflow)
